@@ -10,11 +10,10 @@ import time
 class QRydSimulatorJob(Job):
     _async = True
 
-    def __init__(self, backend, job_url, token, options, circuit):
+    def __init__(self, backend, job_url, session, options, circuit):
         super().__init__(backend, job_url.split("/")[-1])
 
-        self._session = requests.Session()
-        self._session.headers.update({"X-API-Key": token})
+        self._session = session
         self._job_url = job_url
         self._circuit = circuit
         self._memory = options["memory"]
@@ -48,7 +47,7 @@ class QRydSimulatorJob(Job):
             status = JobStatus.ERROR
         return status
 
-    def result(self, timeout=None, wait=0.5):
+    def result(self, timeout=None, wait=0.2):
         result = self._wait_for_result(timeout, wait)
         return Result.from_dict(
             {
@@ -59,6 +58,7 @@ class QRydSimulatorJob(Job):
                             "noise": result["noise"],
                             "method": result["method"],
                             "device": result["device"],
+                            "precision": result["precision"],
                             "num_qubits": result["num_qubits"],
                             "num_clbits": result["num_clbits"],
                             "fusion_max_qubits": result["fusion_max_qubits"],
@@ -88,7 +88,7 @@ class QRydSimulatorJob(Job):
             }
         )
 
-    def _wait_for_result(self, timeout=None, wait=0.5):
+    def _wait_for_result(self, timeout, wait):
         start_time = time.time()
         while True:
             elapsed = time.time() - start_time
