@@ -1,12 +1,14 @@
 from qiskit.providers import ProviderV1 as Provider
 from qiskit.providers.providerutils import filter_backends
 from .qryd_backend import QRydSimulator
+import requests
 
 
 class QRydProvider(Provider):
     def __init__(self, token):
         super().__init__()
-        self.token = token
+        self.session = requests.Session()
+        self.session.headers.update({"X-API-Key": token})
 
     def backends(self, name=None, filters=None, **kwargs):
         backends = [
